## 2.59.10 (2022-06-03)

`stripe`: update a few signatures (#7978)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 2.59.9 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 2.59.8 (2022-02-28)

Add stripe.util.convert_to_stripe_object (#7386)

## 2.59.7 (2022-02-25)

Improve annotation for stripe DeletableAPIResource delete method (#7230)

## 2.59.6 (2022-02-07)

Improve a bunch of `__(deep)copy__` methods (#7148)

## 2.59.5 (2022-01-31)

Upgrade black version (#7089)

## 2.59.3 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 2.59.2 (2021-12-21)

add stripe.util.populate_headers (#6637)

fill out api methods for stripe.Customer (#6638)

fill out api stubs for stripe.Account (#6639)

fill out api stubs for stripe.SubscriptionItem (#6640)

## 2.59.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

